@@ -769,6 +769,7 @@ class AptInput:
         exp = []
         dith = []
         aperture = []
+        pps_aperture = []
         targ1 = []
         targ2 = []
         ra = []
@@ -832,6 +833,10 @@ class AptInput:
                 elif (len(line) > 1):
                     elements = line.split()
 
+                    # If we hit the Glossary at the end, we can stop
+                    if elements[0] == 'Glossary':
+                        break
+
                     # Look for lines that give visit/observation numbers
                     if line[0:2] == '* ':
                         paren = line.rfind('(')
@@ -864,8 +869,6 @@ class AptInput:
 
                         # The exception to this rule is TA images.
                         # These have Exp values of 0. Sigh.
-
-
                         if ((int(elements[1]) > 0) & ('NRC' in elements[4]
                                                          or 'NIS' in elements[4]
                                                          or 'FGS' in elements[4]
@@ -901,6 +904,7 @@ class AptInput:
                             exnum = str(elements[2]).zfill(5)
                             exp.append(exnum)
                             dith.append(int(elements[3]))
+                            pps_aperture.append(elements[4])
 
                             ap = elements[4]
                             if ('GRISMR_WFSS' in elements[4]):
@@ -932,12 +936,12 @@ class AptInput:
                             observation_id.append("V{}P{}{}{}{}".format(vid, '00000000', vgrp, seq, act))
                             # act_counter += 1
 
-                    except ValueError as e:
+                    except (ValueError, IndexError) as e:
                         if verbose:
                             self.logger.info('Skipping line:\n{}\nproducing error:\n{}'.format(line, e))
                         pass
 
-        pointing = {'exposure': exp, 'dither': dith, 'aperture': aperture,
+        pointing = {'exposure': exp, 'dither': dith, 'aperture': aperture, 'pps_aperture': pps_aperture,
                     'targ1': targ1, 'targ2': targ2, 'ra': ra, 'dec': dec,
                     'basex': basex, 'basey': basey, 'dithx': dithx,
                     'dithy': dithy, 'v2': v2, 'v3': v3, 'idlx': idlx,
