@@ -28,10 +28,12 @@ from astropy.coordinates import SkyCoord
 from astroquery.simbad import Simbad
 import batman
 from bokeh.plotting import show
+from bokeh.layouts import column
 from hotsoss import utils as hu, plotting, locate_trace
 import numpy as np
-import synphot as sphot
+from scipy import ndimage
 
+from mirage.catalogs import model_atmosphere as ma
 from mirage.seed_image import save_seed, segmentation_map
 from mirage.dark import dark_prep
 from mirage.logging import logging_functions
@@ -58,8 +60,8 @@ def run_required(func):
     @wraps(func)
     def _run_required(*args, **kwargs):
         """Check that the 'tso' attribute is not None"""
-        if args[0].tso_order1_ideal is None:
-            print("No simulation found! Please run the 'simulate' method first.")
+        if args[0].tso_ideal is None:
+            print("No simulation found! Please run the 'create' method first.")
 
         else:
             return func(*args, **kwargs)
@@ -72,7 +74,7 @@ class SossSim():
     Generate NIRISS SOSS time series observations
     """
     def __init__(self, ngrps=2, nints=1, star=None, planet=None, tmodel=None, filter='CLEAR',
-                 subarray='SUBSTRIP256', orders=[1, 2], paramfile=None, obs_date=None, target='New Target',
+                 subarray='SUBSTRIP256', orders=[1, 2, 3], paramfile=None, obs_date=None, target='New Target',
                  title=None, offline=True, test=False, override_dark=None, verbose=True):
         """
         Initialize the TSO object and do all pre-calculations
@@ -126,8 +128,10 @@ class SossSim():
         self._star = None
         self.ref_params = {"INSTRUME": "NIRISS", "READPATT": "NISRAPID", "EXP_TYPE": "NIS_SOSS", "DETECTOR": "NIS", "PUPIL": "GR700XD", "DATE-OBS": "2020-07-28", "TIME-OBS": "00:00:00", "INSTRUMENT": "NIRISS"}
 
-        # Additional parmeters
+        # Additional parameters
         self.orders = orders
+        self.wave = hu.wave_solutions(subarray)
+        self.avg_wave = None
         self.groupgap = 0
         self.nframes = self.nsample = 1
         self.nresets = self.nresets1 = self.nresets2 = 1
@@ -142,6 +146,9 @@ class SossSim():
         self.readpatt = 'NISRAPID'
         self.paramfile = paramfile
 
+        # Pupil wheel position to set trace tilt
+        self.PWCPOS = 245.76
+
         # Set instance attributes for the target
         self.lines = at.Table(names=('name', 'profile', 'x_0', 'amp', 'fwhm', 'flux'), dtype=('S20', 'S20', float, float, 'O', 'O'))
         self.star = star
@@ -167,6 +174,16 @@ class SossSim():
             The profile to use, ['voigt', 'lorentz', 'gaussian']
         name: str
             A name for the line
+
+        Examples
+        --------
+        from mirage.soss_simulator import SossBlackbodySim
+        import astropy.units as q
+        bb = SossBlackbodySim(run=False)
+        bb.add_line(2*q.um, max(bb.star[1])*1.5, 0.005*q.um)
+        bb.lines # See list of added lines
+        bb.create()
+        bb.plot(noise=False)
         """
         # Check the profile
         profiles = {'voigt': Voigt1D, 'gaussian': Gaussian1D, 'lorentz': Lorentz1D}
@@ -203,16 +220,16 @@ class SossSim():
         self.lines.add_row([name, profile, x_0, amplitude, fwhm, line])
 
     @run_required
-    def add_noise(self):
+    def add_noise(self, override_refs=None, skip_dark=False):
         """
         Run the signal data through the ramp generator
         """
-        self.message("Starting noise generator...")
+        self.logger.info("Starting noise generator...")
         start = time.time()
 
         # Generate segmentation map with correct dimensions
-        self.segmap = segmentation_map.SegMap()
-        self.segmap.ydim = self.nrows
+        segmap = segmentation_map.SegMap()
+        segmap.ydim = self.nrows
 
         # Prepare dark current exposure if needed.
         if self.override_dark is None:
@@ -220,35 +237,57 @@ class SossSim():
             d = dark_prep.DarkPrep(offline=self.offline)
             d.paramfile = self.paramfile
             d.prepare()
-            use_darks = d.dark_files
+            self.use_darks = d.dark_files
         else:
-            self.logger.info('\noverride_dark is set. Skipping call to dark_prep and using these files instead.')
-            use_darks = self.override_dark
+            self.logger.info('Override_dark is set. Skipping call to dark_prep.')
+            self.use_darks = self.override_dark
 
         # Make a seed files split like the dark file
-        if isinstance(use_darks, str):
-            use_darks = [use_darks]
+        if isinstance(self.use_darks, str):
+            self.use_darks = [self.use_darks]
+
+        # Set darks to all zeros if skip_dark
+        if skip_dark:
+            self.logger.info('skip_dark is set. Setting dark frames to all zeroes.')
+            for dfile in self.use_darks:
+                hdu = fits.open(dfile)
+                hdu[1].data *= 0.
+                hdu[2].data *= 0.
+                hdu[3].data *= 0.
+                hdu[4].data *= 0.
+                hdu.flush()
+                hdu.close()
 
         nint = 0
-        nfiles = len(use_darks)
+        nfiles = len(self.use_darks)
         self.tso = np.empty_like(self.tso_ideal)
-        for n, dfile in enumerate(use_darks):
+        self.obs = []
+        for n, dfile in enumerate(self.use_darks):
+            self.logger.info('Using dark file {}/{}: {}'.format(n + 1, len(self.use_darks), dfile))
             dhead = fits.getheader(dfile)
             dnint = dhead['NINTS']
 
-            # Save the raw signal as a seed image
-            seed_seg = self.tso_ideal[nint:nint + dnint, :, :, :]
+            # Get the appropriate seed image segment
+            seed_seg = self.tso_ideal[nint:nint + dnint, :, :, :].astype(np.float64)
+
+            # NaNs and infs break np.random.poisson
+            seed_seg[np.where(np.isnan(seed_seg))] = 0.
+            seed_seg[np.where(np.isinf(seed_seg))] = 0.
+
+            # Save the seed image segment to file
             seedfile, seedinfo = save_seed.save(seed_seg, self.paramfile, self.params, True, False, 1., 2048, (self.nrows, self.ncols), {'xoffset': 0, 'yoffset': 0}, 1, frametime=self.frame_time)
 
             # Combine into final observation
             self.logger.info('Running observation generator for segment {}/{}'.format(n, nfiles))
             obs = obs_generator.Observation(offline=self.offline)
+
+            # Add simulation data
             obs.linDark = dfile
             obs.seed = seed_seg
-            obs.segmap = self.segmap
+            obs.segmap = segmap
             obs.seedheader = seedinfo
             obs.paramfile = self.paramfile
-            obs.create()
+            obs.create(override_refs=override_refs)
 
             if nfiles > 1:
                 os.system('mv {} {}'.format(seedfile, seedfile.replace('_seed_image.fits', '_seg{}_part001_seed_image.fits'.format(str(n + 1).zfill(3)))))
@@ -256,14 +295,68 @@ class SossSim():
             # Save ramp to tso attribute
             self.tso[nint:nint + dnint, :, :, :] = obs.raw_outramp
 
+            # Save obs object
+            self.obs.append(obs)
+
             # Pickup where last segment left off
             nint += dnint
 
-        # Log it
-        self.logger.info('\nSOSS simulator complete')
-        self.message('Noise model finished: {} {}'.format(round(time.time() - start, 3), 's'))
+        self.logger.info('SOSS simulator complete')
+        self.logger.info('Noise model finished: {} {}'.format(round(time.time() - start, 3), 's'))
 
-    def create(self, n_jobs=-1, noise=True, override_dark=None, **kwargs):
+        return obs.output_files
+
+    @property
+    def avg_wave(self):
+        """
+        Getter for nominal wavelength value in each column for all orders
+        """
+        return self._avg_wave
+
+    @avg_wave.setter
+    def avg_wave(self, wave_sol):
+        """
+        Setter for the nominal wavelength value in each column for all orders
+
+        Parameters
+        ----------
+        wave_sol: sequence
+            The wavelength solutions. Must be an array of shape (2, 2048), or (3, 2048)
+        """
+        if wave_sol is None:
+            self._avg_wave = np.mean(self.wave, axis=1)
+            self.wave_name = 'default'
+
+        else:
+
+            # Wave name provided
+            if isinstance(wave_sol, tuple):
+                wave_sol, self.wave_name = wave_sol
+
+            # No wave name provided
+            else:
+                self.wave_name = 'custom'
+
+            # Dimensions of input nominal wavelengths
+            dims = wave_sol.shape
+
+            # Make sure it is 2048 columns wide
+            if dims[-1] != 2048:
+                raise ValueError('{} columns provided but wavelength solutions must be 2048 pixels wide.'.format(dims[-1]))
+
+            # Ensure monotonically decreasing due to native trace orientation
+            wave_sol = np.sort(wave_sol, axis=1)[:, ::-1]
+
+            # Set the attribute
+            self._avg_wave = wave_sol
+
+            # Generate new PSFs here!
+            soss_trace.SOSS_psf_cube(filt='CLEAR', order=1, subarray='SUBSTRIP256', generate=True, mprocessing=True, wave_sol=wave_sol, dirname=self.wave_name)
+
+            # Reset PSFs
+            self._reset_psfs()
+
+    def create(self, n_jobs=-1, noise=True, override_dark=None, max_frames=50, **kwargs):
         """
         Create the simulated 4D ramp data given the initialized TSO object
 
@@ -271,10 +364,12 @@ class SossSim():
         ----------
         n_jobs: int
             The number of cores to use in multiprocessing
-        tparams: dict
-            The transit parameters of the system
-        supersample_factor: int
-            The
+        noise: bool
+            Include noise model in simulation
+        override_dark: str
+            The path to a dark file that should override the default dark
+        max_frames: int
+            The max number of frames to chunk the simulation into to save memory
 
         Example
         -------
@@ -321,15 +416,14 @@ class SossSim():
         self._reset_psfs()
 
         # Logging
-        self.logger.info('\n\nRunning soss_simulator....\n')
-        self.logger.info('Using parameter file: ')
-        self.logger.info('{}'.format(self.paramfile))
+        self.logger.info('Running soss_simulator....')
+        self.logger.info('Using parameter file: {}'.format(self.paramfile or 'None'))
         begin = time.time()
 
         # Make a simulation of all ones to save time
         if self.test:
 
-            self.message("Generating test simulation of shape {}...".format(self.dims))
+            self.logger.info("Generating test simulation of shape {}...".format(self.dims))
             self.tso_order1_ideal = self.tso_order2_ideal = np.ones((self.nints * self.ngrps, 256, 2048))
 
         # Make a true simulation
@@ -340,7 +434,6 @@ class SossSim():
                 n_jobs = max_cores
 
             # Chunk along the time axis so results can be dumped into a file and then deleted
-            max_frames = 50
             nints_per_chunk = max_frames // self.ngrps
             nframes_per_chunk = self.ngrps * nints_per_chunk
 
@@ -350,11 +443,13 @@ class SossSim():
             n_chunks = len(time_chunks)
 
             # Iterate over chunks
-            self.message('Simulating {target} in {title}\nConfiguration: {subarray} + {filter}\nGroups: {ngrps}, Integrations: {nints}\n'.format(**self.info))
+            self.logger.info('Simulating {} in {}'.format(self.target, self.title))
+            self.logger.info('Configuration: {} + {}'.format(self.subarray, self.filter))
+            self.logger.info('Groups: {}, Integrations: {}'.format(self.ngrps, self.nints))
             for chunk, (time_chunk, inttime_chunk) in enumerate(zip(time_chunks, inttime_chunks)):
 
                 # Run multiprocessing to generate lightcurves
-                self.message('Constructing frames for chunk {}/{}...'.format(chunk + 1, n_chunks))
+                self.logger.info('Constructing frames for chunk {}/{}...'.format(chunk + 1, n_chunks))
                 start = time.time()
 
                 # Get transit model for the current time chunk
@@ -381,7 +476,7 @@ class SossSim():
                     pool = ThreadPool(n_jobs)
                     func = partial(soss_trace.psf_lightcurve, time=time_chunk)
                     data = list(zip(psfs, tmodels))
-                    lightcurves = np.asarray(pool.starmap(func, data), dtype=np.float16)
+                    lightcurves = np.asarray(pool.starmap(func, data), dtype=np.float64)
                     pool.close()
                     pool.join()
                     del pool
@@ -409,7 +504,7 @@ class SossSim():
                     # Clear memory
                     del frames, lightcurves, psfs
 
-                self.message('Chunk {}/{} finished: {} {}'.format(chunk + 1, n_chunks, round(time.time() - start, 3), 's'))
+                self.logger.info('Chunk {}/{} finished: {} {}'.format(chunk + 1, n_chunks, round(time.time() - start, 3), 's'))
 
         # Trim SUBSTRIP256 array if SUBSTRIP96
         if self.subarray == 'SUBSTRIP96':
@@ -426,18 +521,53 @@ class SossSim():
                 setattr(self, order_name, full)
                 del full
 
-        # Reshape into (nints, ngrps, y, x)
+        # Rotate and reshape data
         for order in self.orders:
+
+            # Name of order
             order_name = 'tso_order{}_ideal'.format(order)
+
+            # Rotate trace given relative pupil wheel position
+            pwpos = self.PWCPOS - 245.883
+            if pwpos != 0:
+                rot_order = ndimage.rotate(getattr(self, order_name), pwpos, axes=(-2, -1), reshape=False)
+                setattr(self, order_name, rot_order)
+
+            # Reshape into (nints, ngrps, y, x)
             setattr(self, order_name, getattr(self, order_name).reshape(self.dims).astype(np.float64))
 
         # Make ramps and add noise to the observations
+        obs_files = []
         if noise:
-            self.add_noise(**kwargs)
+            obs_files = self.add_noise(**kwargs)
         else:
             self.tso = self.tso_ideal
 
-        self.message('\nTotal time: {} {}'.format(round(time.time() - begin, 3), 's'))
+        # Add input data if available
+        for ofile in obs_files:
+            temp = fits.open(ofile, mode='update')
+            starhdr = fits.Header()
+            starhdr.append(('WUNIT', 'um', 'Wavelength unit'))
+            starhdr.append(('FUNIT', 'erg/s/cm2/A', 'Flux density unit'))
+            starhdu = fits.BinTableHDU.from_columns([fits.Column(name='WAVELENGTH', array=self.star[0].value, format='D'), fits.Column(name='FLUX', array=self.star[1].value, format='D')], header=starhdr, name='STAR')
+            temp.insert(-1, starhdu)
+            if self.planet is not None:
+                planethdr = fits.Header()
+                planethdr.append(('WUNIT', 'um', 'Wavelength unit'))
+                planethdr.append(('T0', self.tmodel.t0, 'Transit center [JD]'))
+                planethdr.append(('A', self.tmodel.a, 'Semimajor-axis [a/R*]'))
+                planethdr.append(('INC', self.tmodel.inc, 'Inclination [deg]'))
+                planethdr.append(('ECC', self.tmodel.ecc, 'Eccentricity'))
+                planethdr.append(('OMEGA', self.tmodel.w, 'Omega value'))
+                planethdr.append(('LD', self.tmodel.limb_dark, 'Limb darkening profile used'))
+                planethdr.append(('TEFF', self.tmodel.teff, 'Effective temperature [K]'))
+                planethdr.append(('LOGG', self.tmodel.logg, 'Log surface gravity [dex]'))
+                planethdr.append(('FEH', self.tmodel.feh, 'Metallicity'))
+                planethdu = fits.BinTableHDU.from_columns([fits.Column(name='WAVELENGTH', array=self.planet[0].value, format='D'), fits.Column(name='TRANSMISSION', array=self.planet[1], format='D')], header=planethdr, name='PLANET')
+                temp.insert(-1, planethdu)
+            temp.flush()
+
+        self.logger.info('\nTotal time: {} {}'.format(round(time.time() - begin, 3), 's'))
 
     @property
     def filter(self):
@@ -476,8 +606,13 @@ class SossSim():
     def info(self):
         """Summary table for the observation settings"""
         # Pull out relevant attributes
-        track = ['_ncols', '_nrows', '_nints', '_ngrps', '_nresets', '_subarray', '_filter', '_obs_datetime', '_orders', 'ld_profile', '_target', 'title', 'ra', 'dec']
+        track = ['_ncols', '_nrows', '_nints', '_ngrps', '_nresets', '_subarray', '_filter', '_obs_datetime', '_orders', 'ld_profile', '_target', 'title', 'ra', 'dec', 't0', 'per', 'rp', 'a', 'inc', 'ecc', 'w', 'u', 'limb_dark', 'teff', 'logg', 'feh']
         settings = {key.strip('_'): val for key, val in self.__dict__.items() if key in track}
+
+        # Display orbital parameters if available
+        if getattr(self, '_tmodel', None) is not None:
+            settings.update({key: val for key, val in self._tmodel.__dict__.items() if key in track})
+
         return settings
 
     def message(self, message_text):
@@ -713,7 +848,6 @@ class SossSim():
 
         # Set the dependent quantities
         self.wave = hu.wave_solutions(self.subarray)
-        self.avg_wave = np.mean(self.wave, axis=1)
         self.coeffs = locate_trace.trace_polynomial(subarray=self.subarray)
 
         # Reset data, time and psfs
@@ -769,8 +903,8 @@ class SossSim():
             # Check the wavelength range
             spec_min = np.nanmin(spectrum[0][spectrum[0] > 0.])
             spec_max = np.nanmax(spectrum[0][spectrum[0] > 0.])
-            sim_min = np.nanmin(self.wave[self.wave > 0.]) * q.um
-            sim_max = np.nanmax(self.wave[self.wave > 0.]) * q.um
+            sim_min = np.nanmin(self.avg_wave[self.avg_wave > 0.]) * q.um
+            sim_max = np.nanmax(self.avg_wave[self.avg_wave > 0.]) * q.um
             if spec_min > sim_min or spec_max < sim_max:
                 print("Wavelength range of input spectrum ({} - {} um) does not cover the {} - {} um range needed for a complete simulation. Interpolation will be used at the edges.".format(spec_min, spec_max, sim_min, sim_max))
 
@@ -821,6 +955,47 @@ class SossSim():
         else:
             return fig
 
+    def plot_input(self, **kwargs):
+        """
+        Plot the 1d stellar spectrum, planet transmission spectrum, and transit lightcurve used as input where available
+        """
+        # Plot the data from the 'star' attribute
+        if self.star is not None:
+
+            # Input data
+            sfig = plotting.plot_spectrum(self.star[0], self.star[1], legend='Input Stellar Spectrum')
+            pfig = None
+            tfig = None
+
+            # Plot the data from the 'planet' attribute
+            if self.planet is not None:
+
+                pfig = plotting.plot_spectrum(self.planet[0], self.planet[1], ylabel='Transmission', legend='Input Planet Transmission', color='green')
+
+            # Plot the transit model
+            if self.tmodel is not None:
+
+                # Set orbital parameters with kwargs (e.g. rp=0.5 to see lightcurve at that planetary radius)
+                tmod = copy(self.tmodel)
+                for key, val in kwargs.items():
+                    setattr(tmod, key, val)
+
+                # Make the transit model
+                mod = batman.TransitModel(tmod, self.time.jd)
+                flux = mod.light_curve(tmod)
+                tfig = plotting.plot_spectrum(self.time.jd, flux, xlabel='Time [JD]', ylabel='Transmission', legend='Theoretical Lightcurve')
+
+                # Print the transit model params
+                print('Input Transit Model Parameters\n------------------------------')
+                for key, val in tmod.__dict__.items():
+                    print('{}: {}'.format(key, val))
+
+            show(column(list(filter(None, [sfig, pfig, tfig]))))
+
+        else:
+
+            print("No input to plot. Please set SossSim.star attribute with 1D data.")
+
     @run_required
     def plot_ramp(self, order=None, noise=True, draw=True):
         """
@@ -923,7 +1098,7 @@ class SossSim():
                 # that we can convert the flux at each wavelegth into [ADU/s]
                 response = self.frame_time / (response * q.mJy * ac.c / (wave * q.um)**2).to(self.star[1].unit)
                 flux = np.interp(wave, self.star[0].value, self.star[1].value, left=0, right=0) * self.star[1].unit * response
-                cube = soss_trace.SOSS_psf_cube(filt=self.filter, order=order, subarray=self.subarray) * flux[:, None, None]
+                cube = soss_trace.SOSS_psf_cube(filt=self.filter, order=order, subarray=self.subarray, dirname=self.wave_name) * flux[:, None, None]
                 setattr(self, 'order{}_response'.format(order), response)
                 setattr(self, 'order{}_psfs'.format(order), cube)
 
@@ -960,6 +1135,29 @@ class SossSim():
 
         return tso
 
+    def save_seed_image(self, filepath=None):
+        """
+        Save the seed image (no noise model) to a FITS file
+
+        Parameters
+        ----------
+        filepath: str (optional)
+            A custom filepath for the seed image
+        """
+        # Get the appropriate seed image segment
+        seed_seg = self.tso_ideal.astype(np.float64)
+
+        # NaNs and infs break np.random.poisson
+        seed_seg[np.where(np.isnan(seed_seg))] = 0.
+        seed_seg[np.where(np.isinf(seed_seg))] = 0.
+
+        # Write the file
+        seedfile, seedinfo = save_seed.save(seed_seg, self.paramfile, self.params, True, False, 1., 2048,
+                                            (self.nrows, self.ncols), {'xoffset': 0, 'yoffset': 0}, 1,
+                                            frametime=self.frame_time, filename=filepath)
+
+        return seedfile
+
     @property
     def star(self):
         """Getter for the stellar data"""
@@ -976,7 +1174,7 @@ class SossSim():
         """
         # Check if the star has been set
         if spectrum is None:
-            self.message("No star to simulate! Please set the self.star attribute!")
+            self.logger.info("No star to simulate! Please set the self.star attribute!")
             self._star = None
 
         else:
@@ -1007,13 +1205,15 @@ class SossSim():
             # Check the wavelength range
             spec_min = np.nanmin(spectrum[0][spectrum[0] > 0.])
             spec_max = np.nanmax(spectrum[0][spectrum[0] > 0.])
-            sim_min = np.nanmin(self.wave[self.wave > 0.]) * q.um
-            sim_max = np.nanmax(self.wave[self.wave > 0.]) * q.um
+            sim_min = np.nanmin(self.avg_wave[self.avg_wave > 0.]) * q.um
+            sim_max = np.nanmax(self.avg_wave[self.avg_wave > 0.]) * q.um
             if spec_min > sim_min or spec_max < sim_max:
                 print("Wavelength range of input spectrum ({} - {}) does not cover the {} - {} range needed for a complete simulation. Interpolation will be used at the edges.".format(spec_min, spec_max, sim_min, sim_max))
 
-            # Good to go
-            self._star = spectrum
+            # Good to go (Poisson statistics in obs_generator require float16)
+            non_nan = np.invert(np.isnan(spectrum[1]))
+            non_inf = np.invert(np.isinf(spectrum[1]))
+            self._star = [i[non_nan * non_inf] for i in spectrum]
 
     @property
     def subarray(self):
@@ -1043,7 +1243,6 @@ class SossSim():
 
         # Set the dependent quantities
         self.wave = hu.wave_solutions(subarr)
-        self.avg_wave = np.mean(self.wave, axis=1)
         self.coeffs = locate_trace.trace_polynomial(subarray=subarr)
 
         # Get correct reference files
@@ -1138,14 +1337,16 @@ class SossSim():
     @property
     def tso_ideal(self):
         """Getter for TSO data without noise"""
-        if self.tso_order1_ideal is None:
+        # Get ideal data
+        ideal_data = [getattr(self, 'tso_order{}_ideal'.format(order)) for order in self.orders]
+
+        # If no data, return None
+        if len(ideal_data) == 0:
             return None
 
-        if 2 in self.orders:
-            return np.sum([self.tso_order1_ideal, self.tso_order2_ideal], axis=0)
-
+        # Otherwise, return the sum of the orders
         else:
-            return self.tso_order1_ideal
+            return np.sum([getattr(self, 'tso_order{}_ideal'.format(order)) for order in self.orders], axis=0)
 
 
 class SossSpecSim(SossSim):
@@ -1175,6 +1376,7 @@ class SossSpecSim(SossSim):
         if add_planet:
             self.planet = hu.PLANET_DATA
             self.tmodel = hu.transit_params(self.time.jd)
+            self.tmodel.t0 = np.mean(self.time.jd)
 
         # Run the simulation
         if run:
@@ -1183,7 +1385,7 @@ class SossSpecSim(SossSim):
 
 class SossBlackbodySim(SossSim):
     """Generate a SossSim object with a blackbody spectrum"""
-    def __init__(self, ngrps=2, nints=2, teff=1800, filter='CLEAR', subarray='SUBSTRIP256', run=True, add_planet=False, scale=1., **kwargs):
+    def __init__(self, ngrps=2, nints=2, teff=1800, jmag=9.0, filter='CLEAR', subarray='SUBSTRIP256', run=True, add_planet=False, **kwargs):
         """Get the test data and load the object
 
         Parameters
@@ -1194,6 +1396,8 @@ class SossBlackbodySim(SossSim):
             The number of integrations for the exposure
         teff: int
             The effective temperature [K] of the test source
+        jmag: float
+            The J band magnitude to scale to
         filter: str
             The name of the filter to use, ['CLEAR', 'F277W']
         subarray: str
@@ -1202,30 +1406,33 @@ class SossBlackbodySim(SossSim):
             Run the simulation after initialization
         add_planet: bool
             Add a transiting exoplanet
-        scale: int, float
-            Scale the flux by the given factor
         """
         # Generate a blackbody at the given temperature
         bb = BlackBody(temperature=teff * q.K)
         wav = np.linspace(0.5, 2.9, 1000) * q.um
-        flux = (bb(wav) * q.sr / bb.bolometric_flux.value).to(FLAMBDA_CGS_UNITS, q.spectral_density(wav)) * 1E-8 * scale
+        flx = (bb(wav) * q.sr / bb.bolometric_flux.value).to(FLAMBDA_CGS_UNITS, q.spectral_density(wav))
+
+        # Scale model spectrum to user-input J-band
+        flx = ma.scale_spectrum(wav, flx, jmag)
 
         # Initialize base class
-        super().__init__(ngrps=ngrps, nints=nints, star=[wav, flux], subarray=subarray, filter=filter, **kwargs)
+        super().__init__(ngrps=ngrps, nints=nints, star=[wav, flx], subarray=subarray, filter=filter, **kwargs)
 
         # Add planet
         if add_planet:
             self.planet = hu.PLANET_DATA
             self.tmodel = hu.transit_params(self.time.jd)
+            self.tmodel.t0 = np.mean(self.time.jd)
+            self.tmodel.teff = teff
 
-        # Run the simulation
+            # Run the simulation
         if run:
             self.create()
 
 
 class SossModelSim(SossSim):
     """Generate a SossSim object with a theoretical ATLAS or PHOENIX stellar spectrum of choice"""
-    def __init__(self, ngrps=2, nints=2, teff=5700.0, logg=4.0, feh=0.0, alpha=0.0, jmag=9.0, models='ck04models', filter='CLEAR', subarray='SUBSTRIP256', run=True, add_planet=False, scale=1., **kwargs):
+    def __init__(self, ngrps=2, nints=2, teff=5700.0, logg=4.0, feh=0.0, alpha=0.0, jmag=9.0, stellar_model='phoenix', filter='CLEAR', subarray='SUBSTRIP256', run=True, add_planet=False, scale=1., **kwargs):
         """Get the test data and load the object
 
         Parameters
@@ -1257,34 +1464,29 @@ class SossModelSim(SossSim):
         scale: int, float
             Scale the flux by the given factor
         """
-        # # Retrieve PHOENIX or ATLAS stellar models:
-        # if stellar_model.lower() == 'phoenix':
-        #     w, f = model_atmospheres.get_phoenix_model(feh, alpha, teff, logg)
-        # elif stellar_model.lower() == 'atlas':
-        #     w, f = model_atmospheres.get_atlas_model(feh, teff, logg)
-        #
-        # # Now scale model spectrum to user-input J-band:
-        # f = model_atmospheres.scale_spectrum(w, f, jmag)
+        # Retrieve stellar model
+        if stellar_model.lower() == 'phoenix':
+            wav, flx = ma.get_phoenix_model(feh, alpha, teff, logg)
+        elif stellar_model.lower() == 'atlas':
+            wav, flx = ma.get_atlas_model(feh, teff, logg)
 
-        # TODO: Retrieve stellar model (https://synphot.readthedocs.io/en/latest/#id13)
-        # TODO: and trash the whole model_atmospheres.py module
-        spectrum = sphot.icat(models, teff, feh, logg) # TODO: Where is icat function?
-        bandpass = sphot.spectrum.SpectralElement.from_filter('2mass_j')
-        obs = sphot.observation.Observation(spectrum, bandpass)
-
-        sp_norm = spectrum.normalize(jmag, band=obs.bandpass)
-        w = sp_norm.waveset
-        f = sp_norm(w)
+        # Scale model spectrum to user-input J-band
+        flx = ma.scale_spectrum(wav, flx, jmag)
 
         # Initialize base class
-        super().__init__(ngrps=ngrps, nints=nints, star=[w, f], subarray=subarray, filter=filter, **kwargs)
+        super().__init__(ngrps=ngrps, nints=nints, star=[wav, flx], subarray=subarray, filter=filter, **kwargs)
 
         # Add planet
         if add_planet:
             self.planet = hu.PLANET_DATA
             self.tmodel = hu.transit_params(self.time.jd)
+            self.tmodel.t0 = np.mean(self.time.jd)
+            self.tmodel.teff = teff
+            self.tmodel.logg = logg
+            self.tmodel.feh = feh
+            self.tmodel.alpha = alpha
 
-        # Run the simulation
+            # Run the simulation
         if run:
             self.create()
 
