@@ -9,6 +9,7 @@ Use
 import os
 import pkg_resources
 
+from astropy.time import Time
 import astropy.units as u
 import numpy as np
 
@@ -24,6 +25,8 @@ EXPTYPES = {"nircam": {"imaging": "NRC_IMAGE", "ts_imaging": "NRC_TSIMAGE",
                        "wfss": "NIS_WFSS", "soss": "NIS_SOSS"},
             "fgs": {"imaging": "FGS_IMAGE"}}
 
+DISPERSED_MODES = ['wfss', 'ts_grism']
+
 # Number of detector resets prior to the start of an exposure
 NUM_RESETS_BEFORE_EXP = {"nircam": {"full": 0, "sub": 1},
                          "niriss": {"full": 0, "sub": 1},
@@ -167,6 +170,7 @@ STANDARD_LOGFILE_NAME = 'mirage_latest.log'
 MODULE_PATH = pkg_resources.resource_filename('mirage', '')
 CONFIG_DIR = os.path.join(MODULE_PATH, 'config')
 NIRISS_GHOST_GAP_FILE = os.path.join(CONFIG_DIR, 'niriss_ghost_gap_summary.txt')
+NIRISS_GHOST_GAP_URL = 'https://raw.githubusercontent.com/spacetelescope/niriss_ghost/main/niriss_ghost/niriss_ghost_gap_summary.txt'
 DEFAULT_NIRISS_PTSRC_GHOST_FILE = os.path.join(os.path.expandvars('$MIRAGE_DATA'), 'niriss/ghosts/', 'niriss_ghost_cen.fits')
 
 # Vega spectrum to use when translating/normalizing input spectra to a given vegamag
@@ -175,3 +179,7 @@ DEFAULT_NIRISS_PTSRC_GHOST_FILE = os.path.join(os.path.expandvars('$MIRAGE_DATA'
 # For the June 2021 update to the zeropoints (based on updated NIRCam gain values), we used
 # alpha_lyr_stis_010.fits from synphot.
 VEGA_SPECTRUM = 'http://ssb.stsci.edu/cdbs/calspec/alpha_lyr_stis_010.fits'
+
+# The base time to use when populating the group times and moving target locations tables.
+# Times are reported relative to this basetime
+TABLE_BASETIME = Time('2000-01-01T00:00:00')
\ No newline at end of file
