@@ -388,7 +388,6 @@ def test_reffile_crds():
     assert np.all(np.array(yam.info['saturation']) == expected_value)
     assert np.all(np.array(yam.info['gain']) == expected_value)
     assert np.all(np.array(yam.info['astrometric']) == expected_value)
-    assert np.all(np.array(yam.info['pixelAreaMap']) == expected_value)
     assert np.all(np.array(yam.info['badpixmask']) == expected_value)
     assert np.all(np.array(yam.info['ipc']) == expected_value)
 
@@ -412,8 +411,6 @@ def test_reffile_crds_full_name():
                                              'nrcb4': 'my_reffiles/my_gain_for_b4.fits'},
                                     'distortion': {'nrcb5': {'f322w2': {'NRC_IMAGE': 'my_reffiles/my_distortion_for_b5.asdf'}},
                                                    'nrcb4': {'f150w': {'NRC_IMAGE': 'my_reffiles/my_distortion_for_b4.asdf'}}},
-                                    'area': {'nrcb5': {'f322w2': {'clear': {'nrc_image': 'my_reffiles/my_pam_for_b5.fits'}}},
-                                             'nrcb4': {'f150w': {'clear': {'nrc_image': 'my_reffiles/my_pam_for_b4.fits'}}}},
                                     'transmission': {'nrcb5': {'f322w2': {'clear': 'my_reffiles/my_transmission_for_b5.fits'},
                                                                'f444w': {'clear': 'my_reffiles/my_transmission_for_b5.fits'},
                                                                'f335m': {'clear': 'my_reffiles/my_transmission_for_b5.fits'},
@@ -444,7 +441,6 @@ def test_reffile_crds_full_name():
                                     'saturation': 'my_niriss_saturation.fits',
                                     'gain': 'my_niriss_gain.fits',
                                     'distortion': {'F115W': {'nis_image': 'my_niriss_disotrtion.asdf'}},
-                                    'area': {'clear': {'f115w': {'nis_image': 'my_niriss_area.fits'}}},
                                     'transmission': {'clear': {'f115w': 'my_niriss_transmission.fits'},
                                                      'gr150c': {'f115w': 'my_niriss_gr_transmission.fits'}
                                                      },
@@ -510,11 +506,9 @@ def test_reffile_crds_full_name():
         assert yam.info['badpixmask'][index] == 'my_reffiles/my_bpm_for_b5.fits'
     for index in match_nrc_sw_distortion_area:
         assert yam.info['astrometric'][index] == 'my_reffiles/my_distortion_for_b4.asdf'
-        assert yam.info['pixelAreaMap'][index] == 'my_reffiles/my_pam_for_b4.fits'
         assert yam.info['transmission'][index] == 'my_reffiles/my_transmission_for_b4.fits'
     for index in match_nrc_lw_distortion_area:
         assert yam.info['astrometric'][index] == 'my_reffiles/my_distortion_for_b5.asdf'
-        assert yam.info['pixelAreaMap'][index] == 'my_reffiles/my_pam_for_b5.fits'
         assert yam.info['transmission'][index] == 'my_reffiles/my_transmission_for_b5.fits'
     for index in match_nrc_lw_flat:
         assert yam.info['pixelflat'][index] == 'my_reffiles/my_flatfield_for_b5.fits'
@@ -528,7 +522,6 @@ def test_reffile_crds_full_name():
         assert yam.info['badpixmask'][index] == 'my_niriss_badpixmask.fits'
     for info in match_nis_distortion_area:
         assert yam.info['astrometric'][index] == 'my_niriss_disotrtion.asdf'
-        assert yam.info['pixelAreaMap'][index] == 'my_niriss_area.fits'
         assert yam.info['transmission'][index] == 'my_niriss_transmission.fits'
     for info in match_nis_flat:
         assert yam.info['pixelflat'][index] == 'my_niriss_flatfield.fits'
@@ -541,7 +534,6 @@ def test_reffile_crds_full_name():
     for index in list(match_nrc_sw_defaults) + list(match_nrc_lw_defaults):
         assert temp_output_dir in yam.info['superbias'][index]
         assert temp_output_dir in yam.info['astrometric'][index]
-        assert temp_output_dir in yam.info['pixelAreaMap'][index]
         assert temp_output_dir in yam.info['ipc'][index]
 
     # Clean up
